@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-use HTML::Menu::TreeView qw(Tree css jscript style documentRoot size clasic preload);
+use HTML::Menu::TreeView qw(Tree css jscript Style documentRoot size clasic preload);
 use CGI qw(-compile :all  -private_tempfiles);
 use strict;
 my $htpath = documentRoot();
@@ -28,9 +28,9 @@ for(my $i = 0 ; $i < $#lines ; ++$i) {
         }
 }
 documentRoot($htpath);
-style("Crystal");
+Style("Crystal");
 size($size);
-clasic() if(defined param('clasic'));
+clasic(1) if(defined param('clasic'));
 my $zoom =
   '<a href="./crystal.pl?style=Crystal&amp;size=16" class="treeviewLink">16</a>|<a href="./crystal.pl?style=Crystal&amp;size=22" class="treeviewLink" >22</a>|<a href="./crystal.pl?style=Crystal&amp;size=32" class="treeviewLink">32</a>|<a href="./crystal.pl?style=Crystal&amp;size=48" class="treeviewLink">48</a>|<a href="./crystal.pl?style=Crystal&amp;size=64" class="treeviewLink">64</a>|<a href="./crystal.pl?style=Crystal&amp;size=128" class="treeviewLink">128</a>';
 print header(),
